Download - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Documentation

# Download

Download Tabler to get the compiled CSS and JavaScript, source code, or include it with your favorite package managers like npm, yarn and more.

## CDN via unpkg

All files included in `@tabler/core` npm package are available over a unpkg CDN. Use it to deliver cached version of Tabler’s compiled CSS and JS to your project.

    <script src="https://unpkg.com/@tabler/core@1.0.0-beta9/dist/js/tabler.min.js"></script>
    <link rel="stylesheet" href="https://unpkg.com/@tabler/core@1.0.0-beta9/dist/css/tabler.min.css">

You can also include additional Tabler plugins:

    <link rel="stylesheet" href="https://unpkg.com/@tabler/core@1.0.0-beta9/dist/css/tabler-flags.min.css">
    <link rel="stylesheet" href="https://unpkg.com/@tabler/core@1.0.0-beta9/dist/css/tabler-payments.min.css">
    <link rel="stylesheet" href="https://unpkg.com/@tabler/core@1.0.0-beta9/dist/css/tabler-vendors.min.css">

## Package managers

Install Tabler in your Node.js powered apps with the npm package:

    npm install @tabler/core

Tabler uses other packages to enhance the functionality for example charts and input masks. These are not automatically installed to avoid huge dependency trees and need to be installed by using npm install. We support the following packages as of writing.

- apexcharts
- autosize
- choices.js
- countup.js
- flatpickr
- imask
- litepicker
- nouislider
- tom-select

For the complete list of supported packages you can check the peerDependencies section in our package.json